starcluster.templates.user_msgs

Package starcluster :: Package templates :: Module user_msgs |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.templates.user_msgs

      1  #!/usr/bin/env python
      2
      3  active_ebs_cluster = """EBS Cluster '%(cluster_name)s' already exists.
      4
      5  Either choose a different tag name, or stop the EBS cluster using:
      6
      7    $ starcluster stop %(cluster_name)s
      8
      9  This command will put all nodes into a 'stopped' state and preserve their \
     10  local disks. The cluster can later be resumed by passing the -x option to \
     11  the start command. (NOTE: You pay for the local disks when the nodes are \
     12  not running)
     13
     14  Another option is to terminate the existing EBS Cluster using:
     15
     16    $ starcluster terminate %(cluster_name)s
     17
     18  NOTE: Terminating an EBS cluster will destroy the local disks (volumes) \
     19  backing the nodes.
     20  """
     21
     22  stopped_ebs_cluster = """Stopped EBS Cluster '%(cluster_name)s' already exists.
     23
     24  Either choose a different tag name, or start the stopped EBS cluster using:
     25
     26    $ starcluster start %(cluster_name)s -x
     27
     28  Another option is to terminate the existing EBS Cluster using:
     29
     30    $ starcluster terminate %(cluster_name)s
     31
     32  NOTE: Terminating an EBS cluster will destroy the local disks (voluems) \
     33  backing the nodes.
     34  """
     35
     36  cluster_exists = """Cluster with tag name %(cluster_name)s already exists.
     37
     38  If you want to reconfigure the existing instances use the 'restart' command:
     39
     40    $ starcluster restart %(cluster_name)s
     41
     42  This will reboot all of the instances and configure the cluster starting from \
     43  scratch.
     44
     45  Otherwise either choose a different tag name, or terminate the existing \
     46  cluster using:
     47
     48    $ starcluster terminate %(cluster_name)s
     49
     50  """
     51
     52  cluster_started_msg = """
     53
     54  The cluster has been started and configured.
     55  Login to the master node as root by running:
     56
     57      $ starcluster sshmaster %(tag)s
     58
     59  When you are finished using the cluster, run:
     60
     61      $ starcluster stop %(tag)s
     62
     63  to shutdown the cluster and stop paying for service.
     64
     65  If this cluster uses EBS instances then the 'stop' command above will put all \
     66  nodes into a 'stopped' state. The cluster may then be restarted at a later \
     67  time, without losing data, by passing the -x option to the 'start' command.
     68
     69  To completely terminate an EBS cluster:
     70
     71      $ starcluster terminate %(tag)s
     72
     73  NOTE: Terminating an EBS cluster will destroy all volumes backing the nodes.
     74  """
     75
     76  spotmsg = """SPOT INSTANCES ARE NOT GUARANTEED TO COME UP
     77
     78  Spot instances can take a long time to come up and may not come up at all \
     79  depending on the current AWS load and your max spot bid price.
     80
     81  StarCluster will wait indefinitely until all instances come up. If this takes \
     82  too long, you can cancel the start command using CTRL-C and manually wait for \
     83  the spot instances to come up by periodically checking the output of:
     84
     85     $ starcluster listclusters %(tag)s
     86
     87  Once all instances (%(size)d) show up in the output of the 'listclusters' \
     88  command above, re-execute this same start command with the \
     89  --no-create (-x) option:
     90
     91     $ starcluster %(cmd)s
     92
     93  This will use the existing spot instances launched previously and continue \
     94  starting the cluster.
     95  """
     96
     97  version_mismatch = """\
     98  The cluster '%(cluster)s' was created with a newer version of StarCluster \
     99  (%(new_version)s). You're currently using version %(old_version)s.
    100
    101  This may or may not be a problem depending on what's changed between these \
    102  versions, however, it's highly recommended that you use version \
    103  %(old_version)s when using the '%(cluster)s' cluster.\
    104  """
    105